0

+ Family type
0: variable without family
20: family
40: leadership
60: dynamic
80: error

max(Family type + x, 20):
0:  description|help|test|default
1:  multi
2:  type params|validators
4:  property
8:  mode
16: redefine|exists
